OC.L10N.register(
    "twofactor_totp",
    {
    "Enable TOTP" : "Enable TOTP",
    "Verify" : "Verify",
    "Submit" : "Submit"
},
"nplurals=1; plural=0;");
